/* busyMessage.C

   Copyright (C) 1999 by David Rose.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

   To contact the original author of this program, write to:
           David Rose
           224 W. Dryden St Apt. 418
	   Glendale, CA 91202
	   USA

	   drose@lafn.org
   */

#include "system.h"

#include "busyMessage.h"
#include "gtkProgram.h"

#include <unistd.h>

BusyMessage::
BusyMessage(const string &message) : _label(message) {
  layout_window();
  setup();

  // Now we have to wait in the Gtk loop until our window is fully
  // drawn.  This seems to be somewhat problematic.  For some reason,
  // hooks hung on the "draw" event aren't getting called.  And simply
  // waiting for is_drawable() isn't sufficient.  As a best
  // approximation, we'll wait for is_drawable(), and then a little
  // bit more.

  while (!is_drawable()) {
    GtkProgram::_gtk->iteration();
  }

  // We'll set a timeout for a quarter second longer just to give it a
  // chance to pop up.  (Surely there's a better way!)
  _timeout = false;
  connect_to_method(Gtk_Main::timeout(250), this, &got_timeout);
  while (!_timeout) {
    GtkProgram::_gtk->iteration();
  }
}

gint BusyMessage::
got_timeout() {
  _timeout = true;
  return 0;
}

void BusyMessage::
layout_window() {
  set_title("Busy");
  set_border_width(8);

  add(_label);
  _label.show();
}
