/* cdTrackPlayer.h

   Copyright (C) 1999 by David Rose.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

   To contact the original author of this program, write to:
           David Rose
           224 W. Dryden St Apt. 418
	   Glendale, CA 91202
	   USA

	   drose@lafn.org
   */

#ifndef CDTRACKPLAYER_H
#define CDTRACKPLAYER_H

#include <string>

extern "C" {
  #include <cdaudio.h>
}

class CDTrackPlayer {
public:

  // We differentiate between the track number, which starts counting
  // at 1, and the track index, which starts counting at 0.  The
  // constructor expects a track number; all other functions expect a
  // track index.

  CDTrackPlayer(const string &device_name, int track_num);
  ~CDTrackPlayer();

  bool is_valid() const;
  double get_length() const;

  double get_current_time();
  void play(double start, double length);
  void stop();
  bool is_playing();

  int get_start_frame(int track_index) const;
  int get_end_frame(int track_index) const;
  int get_track_length(int track_index) const;

private:
  int _track_index;
  int _first_frame;
  int _last_frame;
  bool _is_valid;

  int _cd_desc;
  struct disc_info _disc;
};

#endif
